@@ -1,15 +1,15 @@
 
-contourpl<-function(data,output,method="MGHD",scale=TRUE){
- z=data
-   if(scale){
+contourpl<-function(input){
+  z=input@data
+  if(input@scale==T){
   z=scale(z)}
-  
+  method=input@method
   xmin=min(z[,1])-1
   xmax=max(z[,1])+1
   ymin=min(z[,2])-1
   ymax=max(z[,2])+1
-  em=output$model
-  G=length(em$gpar$pi)
+  em=input@gpar
+  G=length(em$pi)
   x = seq(xmin,xmax,length.out=50)
   y = seq(ymin,ymax,length.out=50)
   
@@ -20,7 +20,7 @@ contourpl<-function(data,output,method="MGHD",scale=TRUE){
       for(j in 1:length(y)){
         for(k in 1:G){
           xy <- matrix(cbind(x[i],y[j]),1,2)	
-          xyS1[i,j,k] =  dmsghyp(xy, em$gpar[[k]], log=FALSE) 
+          xyS1[i,j,k] =  dmsghyp(xy, em[[k]], log=FALSE) 
           
         }
       }
@@ -31,7 +31,7 @@ contourpl<-function(data,output,method="MGHD",scale=TRUE){
       for(j in 1:length(y)){
         for(k in 1:G){
           xy <- matrix(cbind(x[i],y[j]),1,2)	
-          xyS1[i,j,k] =  ddghypGH(xy, em$gpar[[k]], log=FALSE) 
+          xyS1[i,j,k] =  ddghypGH(xy, em[[k]], log=FALSE) 
           
         }
       }
@@ -42,15 +42,15 @@ contourpl<-function(data,output,method="MGHD",scale=TRUE){
       for(j in 1:length(y)){
         for(k in 1:G){
           xy <- matrix(cbind(x[i],y[j]),1,2)	
-          xyS1[i,j,k] =  dmsghypMS(xy, em$gpar[[k]], log=FALSE) 
+          xyS1[i,j,k] =  dmsghypMS(xy, em[[k]], log=FALSE) 
           
         }
       }
     }
   }
-  zz=xyS1[,,1]*em$gpar$pi[1]
+  zz=xyS1[,,1]*em$pi[1]
   for(k in 2:G){
-    zz=xyS1[,,k]*em$gpar$pi[k]+zz}
+    zz=xyS1[,,k]*em$pi[k]+zz}
   
   contour(x=x,y=y,z=zz, levels=c(.005,.01,.025,.05, .1,.25), main=method,ylim=c(ymin,ymax), xlim=c(xmin,xmax))
-  points(z,col=em$map,pch=em$map)}
\ No newline at end of file
+  points(z,col=input@map,pch=input@map)}
\ No newline at end of file
